"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AllProductsShopsDataRecord = void 0;
const errors_1 = require("../utils/errors");
const db_1 = require("../utils/db");
class AllProductsShopsDataRecord {
    constructor(obj) {
        if (!obj.productName || obj.productName.length > 30) {
            throw new errors_1.ValidationError('Nazwa produktu nie może być pusta, ani przekraczać 30 znaków.');
        }
        if (!obj.productPrice || obj.productPrice > 999999.99) {
            throw new errors_1.ValidationError('Cena musi zostać podana i nie może przekraczać: 999999.99');
        }
        if (obj.description && obj.description.length > 200) {
            throw new errors_1.ValidationError('Opis nie może przekraczać 200 znaków.');
        }
        if (!obj.shopName || obj.shopName.length > 30) {
            throw new errors_1.ValidationError('Nazwa produktu nie może być pusta, ani przekraczać 30 znaków.');
        }
        if (!obj.category || obj.category.length > 30) {
            throw new errors_1.ValidationError('Kategoria produktu nie może być pusta, ani przekraczać 30 znaków.');
        }
        if (obj.url && obj.url.length > 100) {
            throw new errors_1.ValidationError('Adres do strony www nie może przekraczać 100 znaków.');
        }
        this.productId = obj.productId;
        this.productName = obj.productName;
        this.productPrice = obj.productPrice;
        this.description = obj.description;
        this.shopId = obj.shopId;
        this.shopName = obj.shopName;
        this.category = obj.category;
        this.url = obj.url;
    }
    static getAllProductsAndShopsData() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT `products`.`id` AS `productId`, `products`.`name` AS `productName`, `products`.`price` AS `productPrice`, `products`.`description` AS `description`, `products`.`shop_id` AS `shopId`, `shops`.`name` AS `shopName`, `shops`.`category` AS `category`, `shops`.`url` AS `url` FROM `products` JOIN `shops` ON `products`.`shop_id` = `shops`.`id` ORDER BY `products`.`name` ASC");
            return results.map(record => new AllProductsShopsDataRecord(record));
        });
    }
}
exports.AllProductsShopsDataRecord = AllProductsShopsDataRecord;
//# sourceMappingURL=all.products.shops.data.js.map