"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProductRecord = void 0;
const errors_1 = require("../utils/errors");
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
class ProductRecord {
    constructor(obj) {
        if (!obj.name || obj.name.length > 30) {
            throw new errors_1.ValidationError('Nazwa produktu nie może być pusta, ani przekraczać 30 znaków.');
        }
        if (!obj.price || obj.price > 999999.99) {
            throw new errors_1.ValidationError('Cena musi zostać podana i nie może przekraczać: 999999.99');
        }
        if (obj.description && obj.description.length > 200) {
            throw new errors_1.ValidationError('Opis nie może przekraczać 200 znaków.');
        }
        this.id = obj.id;
        this.name = obj.name;
        this.price = obj.price;
        this.description = obj.description;
        this.shop_id = obj.shop_id;
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `products` WHERE `id` = :id", {
                id,
            });
            return results.length > 0 ? new ProductRecord(results[0]) : null;
        });
    }
    static getAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `products`");
            return results.map(product => new ProductRecord(product));
        });
    }
    static getAllProductsFromSingleShop(shopId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT `products`.`id`, `products`.`name`, `products`.`price` FROM `products` JOIN `shops` ON `products`.`shop_id` = `shops`.`id` WHERE `shops`.`id` = :shopId", {
                shopId,
            });
            return results.map(product => new ProductRecord(product));
        });
    }
    static getOneProductFromSingleShop(shopId, productName) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT `products`.`id`, `products`.`name`, `products`.`price`, `products`.`shop_id` FROM `products` WHERE `shop_id` = :shopId AND `name` = :productName", {
                shopId,
                productName,
            });
            return results.map(product => new ProductRecord(product));
        });
    }
    insert() {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            else {
                throw new errors_1.ValidationError('Ten produkt został już dodany.');
            }
            yield db_1.pool.execute("INSERT INTO `products` VALUES(:id, :name, :price, :description, :shop_id)", {
                id: this.id,
                name: this.name,
                price: this.price,
                description: (_a = this.description) !== null && _a !== void 0 ? _a : null,
                shop_id: (_b = this.shop_id) !== null && _b !== void 0 ? _b : null,
            });
            return this.id;
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `products` WHERE `id` = :id", {
                id: this.id,
            });
        });
    }
}
exports.ProductRecord = ProductRecord;
//# sourceMappingURL=product.record.js.map