"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShopRecord = void 0;
const db_1 = require("../utils/db");
const errors_1 = require("../utils/errors");
const uuid_1 = require("uuid");
class ShopRecord {
    constructor(obj) {
        if (!obj.name || obj.name.length > 30) {
            throw new errors_1.ValidationError('Nazwa produktu nie może być pusta, ani przekraczać 30 znaków.');
        }
        if (!obj.category || obj.category.length > 30) {
            throw new errors_1.ValidationError('Kategoria produktu nie może być pusta, ani przekraczać 30 znaków.');
        }
        if (obj.url && obj.url.length > 100) {
            throw new errors_1.ValidationError('Adres do strony www nie może przekraczać 100 znaków.');
        }
        if (typeof obj.lon !== 'number' || typeof obj.lat !== 'number') {
            throw new errors_1.ValidationError('Nie można zlokalizować ogłoszenia.');
        }
        this.id = obj.id;
        this.name = obj.name;
        this.category = obj.category;
        this.url = obj.url;
        this.lat = obj.lat;
        this.lon = obj.lon;
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `shops` WHERE `id` = :id", {
                id,
            });
            return results.length > 0 ? new ShopRecord(results[0]) : null;
        });
    }
    static getAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `shops`");
            return results.map(shop => new ShopRecord(shop));
        });
    }
    static getAllShopsWithTheProduct(productName) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT `shops`.`id`, `shops`.`name`, `shops`.`category`, `shops`.`url`, `shops`.`lat`, `shops`.`lon` FROM `shops` JOIN `products` ON `shops`.`id` = `products`.`shop_id` WHERE `products`.`name` = :productName", {
                productName,
            });
            return results.map(shop => new ShopRecord(shop));
        });
    }
    insert() {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            else {
                throw new errors_1.ValidationError('Ten sklep jest już w bazie danych.');
            }
            yield db_1.pool.execute("INSERT INTO `shops` VALUES(:id, :name, :category, :url, :lat, :lon)", {
                id: this.id,
                name: this.name,
                category: this.category,
                url: (_a = this.url) !== null && _a !== void 0 ? _a : null,
                lat: this.lat,
                lon: this.lon,
            });
            return this.id;
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `shops` WHERE `id` = :id", {
                id: this.id,
            });
        });
    }
}
exports.ShopRecord = ShopRecord;
//# sourceMappingURL=shop.record.js.map